EnumValidator class

Validator that checks if a value is one of a set of allowed values.

Constructors

EnumValidator({required List allowedValues, String message = 'Value is not in the allowed list', bool caseSensitive = true})

Properties

allowedValues List
final
caseSensitive bool
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate(dynamic value) String?
Validates a field value and returns an error message if invalid.

Operators

operator ==(Object other) bool
The equality operator.
inherited