FieldOption class

Option for dropdown fields

Constructors

FieldOption({required String label, required dynamic value, IconData? icon})
FieldOption.fromJson(Map<String, dynamic> json)
Creates a FieldOption from a JSON map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
icon IconData?
Optional icon
final
label String
Display label
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → dynamic
Actual value
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited