NotEqualToValidator class
Validator that checks if a value does not equal a specific value.
Constructors
- NotEqualToValidator({required dynamic targetValue, String message = 'Value must not equal the specified value', bool caseSensitive = true})
Properties
- caseSensitive → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetValue → dynamic
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
dynamic value) → String? - Validates a field value and returns an error message if invalid.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited